@@ -192,9 +192,11 @@ def get_mims_summary_after_prompt_wearstate(wear_state, sec_after, prompt_time,
             # print(swan_pred)
             if swan_pred != wear_state:
                 continue
-            mims_value = df_mims_swan_minute_combined.loc[idx, "MIMS_SAMPLE_NUM"]
-            mims_summary_wearstate += mims_value
-            mims_wearstate_min += 1
+            mims_sample_num = df_mims_swan_minute_combined.loc[idx, "MIMS_SAMPLE_NUM"]
+            if mims_sample_num > 0:
+                mims_value = df_mims_swan_minute_combined.loc[idx, "MIMS_SUM"]
+                mims_summary_wearstate += mims_value
+                mims_wearstate_min += 1
     else:
         mims_summary_wearstate = "NF"
         mims_wearstate_min = "NF"
